local dropvars "*buis* z4projtype_* z4RABrp* z4RABrqt* z11* z5* z4rqt* z4rp*"


******************************************
* This file makes all tables in the paper
* Uses codedsamerged, codedhhmerged, and codedmusdes, codeddusunperdesa, podesextract, codedf1alloc, codedtreatments, codedf4RAB
*******************************************

*******************************************
* Begin with tables that use data from the road survey
* This data is in codedsamerged, but need to merge in a few other things
*******************************************

use jperandomizationdata, clear

*****************************
* Table 2: Randomization regressions
*****************************
dprobit audit zpop totalmesjid totalallocation z4RABnumsubproj  zpercentpoorpra zdistancekec zkadesedyears zkadesage zkadesbengkoktotal  podeszhill, cluster(kecnum)  
testparm *
local regpval = r(p)
outreg using tabletreatmentsrandom, 3aster coefastr se addstat("P val of regression",`regpval') replace title("Are variables random") ctitle("No FE")

dprobit undfpm zpop totalmesjid totalallocation z4RABnumsubproj  zpercentpoorpra zdistancekec zkadesedyears zkadesage zkadesbengkoktotal  podeszhill, cluster(kecnum)  
testparm *
local regpval = r(p)
outreg using tabletreatmentsrandom, 3aster coefastr se addstat("P val of regression",`regpval') append ctitle("No FE")

dprobit fpm zpop totalmesjid totalallocation z4RABnumsubproj  zpercentpoorpra zdistancekec zkadesedyears zkadesage zkadesbengkoktotal  podeszhill if undfpm == 1 , cluster(kecnum)  
testparm *
local regpval = r(p)
outreg using tabletreatmentsrandom, 3aster coefastr se addstat("P val of regression",`regpval') append ctitle("No FE")



**********************
* Table 3 -- summary stats
**********************

use jperoaddata, clear
g str40 varname = ""
g outinfo = .
local numvar = 1

foreach X of var totalprojusd  sharetotalroad sharetotalancil sharetotalother shareroadsand shareroadrock shareroadtop shareroadburuh shareroadother lndiffeall4 lndiffeall4mainancil lndiffeall3mat lndiffeburuh {
	
	local numstd = `numvar' + 1
	qui summ `X' if lndiffeall4mainancil != .
	replace outinfo = r(mean) in `numvar'
	replace outinfo = -1 * r(sd) in `numstd'
	replace varname = "`X'" in `numvar'
	local numvar = `numvar' + 2
}
local numvar = `numvar' - 1
outsheet varname outinfo using tableauditsumstats.out in 1/`numvar', replace


********************************
* Table 4 - Audit effects
***********************************

capture drop varname
capture drop controlmean
capture drop treatmean
capture drop diffmeans
capture drop pval
capture drop diffmeanskabfe
capture drop pvalkabfe
capture drop diffmeansengfe
capture drop pvalengfe
capture drop numobs

g str40 varname = ""
g controlmean = .
g treatmean = .
g diffmeans = .
g pval = .
g diffmeanskabfe = .
g pvalkabfee = .
g diffmeansengfe = .
g pvalengfee = .
g numobs = .
local numvar = 0
g samplevar = .

foreach X of var lndiffeall4  lndiffeall4mainancil lndiffeall3mat lndiffeburuh {
	replace samplevar = 1


	local numvar = `numvar' + 1
	local numvarse = `numvar' + 1
	
	replace varname = "`X'" in `numvar'
	qui summ `X' if audit == 1 & samplevar == 1
	replace treatmean = r(mean) in `numvar'
	qui reg `X' if audit == 1 & samplevar == 1, cluster(kecnum)
	replace treatmean = -1 * _se[_cons] in `numvarse'

	qui summ `X' if audit == 0 & samplevar == 1
	replace controlmean = r(mean) in `numvar'
	qui reg `X' if audit == 0 & samplevar == 1, cluster(kecnum)
	replace controlmean = -1 * _se[_cons] in `numvarse'



	reg `X' audit und fpm if samplevar == 1, cluster(kecnum)
		
	test audit
	replace pval = r(p) in `numvar'
	replace numobs = e(N) in `numvar'
	replace diffmeans = _b[audit] in `numvar'
	replace diffmeans  = -1 * _se[audit] in `numvarse'


	areg `X' audit und fpm if samplevar == 1, cluster(kecnum) absorb(auditstratnum)
	
		
	replace diffmeanskabfe = _b[audit] in `numvar'
	replace diffmeanskabfe =  -1 * _se[audit] in `numvarse'
	
	test audit
	replace pvalkabfe = r(p) in `numvar'
	
	areg `X' audit und fpm if samplevar == 1, cluster(kecnum) absorb(z7enumcode)
	
	
	replace diffmeansengfe = _b[audit] in `numvar'
	replace diffmeansengfe =  -1 * _se[audit] in `numvarse'
	test audit
	replace pvalengfe = r(p) in `numvar'

	local numvar = `numvar' + 1

	
}

outsheet varname controlmean treatmean diffmeans pval diffmeansengfe pvalengfe diffmeanskabfe pvalkabfe numobs using tableauditmeans.out in 1/`numvar', replace


********************************
* Table 5 - Audits - prices vs. quantities 
***********************************

capture drop varname
capture drop controlmean
capture drop treatmean
capture drop diffmeans
capture drop pval
capture drop diffmeanskabfe
capture drop pvalkabfe
capture drop diffmeansengfe
capture drop pvalengfe
capture drop numobs

g str40 varname = ""
g controlmean = .
g treatmean = .
g diffmeans = .
g pval = .
g diffmeanskabfe = .
g pvalkabfee = .
g diffmeansengfe = .
g pvalengfee = .
g numobs = .
local numvar = 0

foreach X of var lndiffpall4  lndiffqtall4 {
	replace samplevar = 1



	local numvar = `numvar' + 1
	local numvarse = `numvar' + 1
	
	replace varname = "`X'" in `numvar'
	qui summ `X' if audit == 1 & samplevar == 1
	replace treatmean = r(mean) in `numvar'
	qui reg `X' if audit == 1 & samplevar == 1, cluster(kecnum)
	replace treatmean = -1 * _se[_cons] in `numvarse'

	qui summ `X' if audit == 0 & samplevar == 1
	replace controlmean = r(mean) in `numvar'
	qui reg `X' if audit == 0 & samplevar == 1, cluster(kecnum)
	replace controlmean = -1 * _se[_cons] in `numvarse'



	reg `X' audit und fpm if samplevar == 1, cluster(kecnum)
		
	test audit
	replace pval = r(p) in `numvar'
	replace numobs = e(N) in `numvar'
	replace diffmeans = _b[audit] in `numvar'
	replace diffmeans  = -1 * _se[audit] in `numvarse'


	areg `X' audit und fpm if samplevar == 1, cluster(kecnum) absorb(auditstratnum)
	
		
	replace diffmeanskabfe = _b[audit] in `numvar'
	replace diffmeanskabfe =  -1 * _se[audit] in `numvarse'
	
	test audit
	replace pvalkabfe = r(p) in `numvar'
	
	areg `X' audit und fpm if samplevar == 1, cluster(kecnum) absorb(z7enumcode)
	
	
	replace diffmeansengfe = _b[audit] in `numvar'
	replace diffmeansengfe =  -1 * _se[audit] in `numvarse'
	test audit
	replace pvalengfe = r(p) in `numvar'

	local numvar = `numvar' + 1

	
}

outsheet varname controlmean treatmean diffmeans pval diffmeansengfe pvalengfe diffmeanskabfe pvalkabfe numobs using tableauditpricequantities.out in 1/`numvar', replace

***************************
* Figure 1 -- empirical CDFs
***************************
set scheme s1color

bys audit: cumul lndiffeall4, g(cdf) equal
g cdf1 = cdf if audit == 1
g cdf0 = cdf if audit == 0
label var cdf1 "Audits"
label var cdf0 "Control"
label var lndiffeall4 "Log(Reported) - Log(Actual) -- Major Items in Road"
sort lndiffeall4
twoway (line cdf1 lndiffeall4, lcolor(maroon)) (line cdf0 lndiffeall4, clpattern(dash) lcolor(blue)), xtick(-1(.25)2) saving(CDF,replace) title("CDF")


***************************
* Figure 1 -- empirical PDFs
***************************

kdensity lndiffeall4 if audit==1, n(200) g(a1x a1y) ep
kdensity lndiffeall4 if audit==0, n(200) g(a0x a0y) ep
label var a1y "Audits"
label var a0y "Control"
label var a0x "Log(Reported) - Log(Actual) -- Major Items in Road"
label var a1x "Log(Reported) - Log(Actual) -- Major Items in Road"
twoway (line a1y a1x, lcolor(maroon)) (line a0y a0x, clpattern(dash) lcolor(blue)), xtick(-1(.25)1.5) saving(PDF,replace) title("PDF")


graph combine CDF.gph PDF.gph, xcommon xsize(7) ysize(4) saving(PDFCDF,replace)
graph export PDFCDF.eps, replace


*************************************
* Table 6 -- auditor findings and survey team findings
*************************************

areg stdz12scorefisik stdz13*, cluster(kecnum) absorb(kecnum)
outreg using tableauditresults.out, 3aster coefastr se  replace title("Audit findings")

areg stdz12scoreadmin stdz13*, cluster(kecnum) absorb(kecnum)
outreg using tableauditresults.out, 3aster coefastr se  append

areg lndiffeall4 stdz13*, cluster(kecnum) absorb(kecnum)
outreg using tableauditresults.out, 3aster coefastr se  append


*************************
* Table 11 - participation results
**************************

capture drop varname
capture drop controlmean
capture drop treatmeanund
capture drop treatmeanfpm
capture drop diffmeansund
capture drop diffmeansfpm
capture drop pvalund
capture drop pvalfpm
capture drop numobs

g str40 varname = ""
g controlmean = .
g treatmeanfpm = .
g treatmeanund = .
g diffmeansund = .
g diffmeansfpm = .
g diffmeansundengfe = .
g diffmeansfpmengfe = .
g diffmeansundfe = .
g diffmeansfpmfe = .
g pvalund = .
g pvalfpm = .
g pvalundengfe = .
g pvalfpmengfe = .
g pvalundfe = .
g pvalfpmfe = .
g numobs = .

foreach X of var lndiffeall4 lndiffeall4mainancil lndiffeall3mat lndiffeburuh {
	replace samplevar = 1
	
		
	local numvar = `numvar' + 1
	local numvarse = `numvar' + 1
	replace varname = "`X'" in `numvar'
	qui summ `X' if und == 1 & samplevar == 1
	replace treatmeanund = r(mean) in `numvar'
	qui reg `X' if und == 1 & samplevar == 1, cluster(kecnum)
	replace treatmeanund = -1 * _se[_cons] in `numvarse'
	

	qui summ `X' if fpm == 1 & samplevar == 1
	replace treatmeanfpm = r(mean) in `numvar'
	qui reg `X' if fpm == 1 & samplevar == 1, cluster(kecnum)
	replace treatmeanfpm = -1 * _se[_cons] in `numvarse'
	
	
	qui summ `X' if und == 0 & fpm == 0 & samplevar == 1
	replace controlmean = r(mean) in `numvar'
	qui reg `X' if und == 1 & fpm == 0 & samplevar == 1, cluster(kecnum)
	replace controlmean = -1 * _se[_cons] in `numvarse'
	
	
	reg `X' audit und fpm if samplevar == 1,  cluster(kecnum)
	replace diffmeansund = _b[und] in `numvar'
	replace diffmeansund  = -1 * _se[und] in `numvarse'
	
	
	replace diffmeansfpm = _b[fpm] in `numvar'
	replace diffmeansfpm = -1 * _se[fpm] in `numvarse'
	
	
	replace numobs = e(N) in `numvar'
	test und
	replace pvalund = r(p) in `numvar'
	test fpm
	replace pvalfpm = r(p) in `numvar'
	
	areg `X' und fpm if samplevar == 1, absorb(kecnum) robust
	replace diffmeansundfe = _b[und] in `numvar'
	replace diffmeansundfe = -1 * _se[und] in `numvarse'
	
	replace diffmeansfpmfe = _b[fpm] in `numvar'
	replace diffmeansfpmfe = -1 * _se[fpm] in `numvarse'
	
	test und
	replace pvalundfe = r(p) in `numvar'
	test fpm
	replace pvalfpmfe = r(p) in `numvar'
	
	
	areg `X' audit und fpm if samplevar == 1, absorb(z7enumcode) cluster(kecnum)
	replace diffmeansundengfe = _b[und] in `numvar'
	replace diffmeansundengfe = -1 * _se[und] in `numvarse'
	
	replace diffmeansfpmengfe = _b[fpm] in `numvar'
	replace diffmeansfpmengfe = -1 * _se[fpm] in `numvarse'
	test und
	replace pvalundengfe = r(p) in `numvar'
	test fpm
	replace pvalfpmengfe = r(p) in `numvar'
	

			
	local numvar = `numvar' + 1
	
}

outsheet varname controlmean treatmeanund diffmeansund pvalund diffmeansundengfe pvalundengfe diffmeansundfe pvalundfe numobs using tableinvitemeans.out in 1/`numvar', replace
outsheet varname controlmean treatmeanfpm diffmeansfpm pvalfpm diffmeansfpmengfe pvalfpmengfe diffmeansfpmfe pvalfpmfe numobs using tablecommentmeans.out in 1/`numvar', replace


***********************************
* Table 12 - Participation results splitting by distribution method
***********************************

capture drop varname
capture drop controlmean
capture drop treatmeanund
capture drop treatmeanfpm
capture drop diffmeans*
capture drop pval*
capture drop numobs

g str40 varname = ""
g controlmean = .
g treatmeanfpm = .
g treatmeanund = .
g diffmeansund = .
g diffmeansfpm = .
g diffmeansundengfe = .
g diffmeansfpmengfe = .
g diffmeansundfe = .
g diffmeansfpmfe = .
g pvalund = .
g pvalfpm = .
g pvalundengfe = .
g pvalfpmengfe = .
g pvalundfe = .
g pvalfpmfe = .
g numobs = .

for var und fpm: g Xsd = X * sd \ g Xnosd = X * !sd

*****
* Distributed by neighborhood heads
*****
foreach X of var lndiffeall4 lndiffeall4mainancil {
	replace samplevar = 1
	
		
	local numvar = `numvar' + 1
	local numvarse = `numvar' + 1
	replace varname = "`X'" in `numvar'
	qui summ `X' if und == 1 & samplevar == 1 & sd == 0
	replace treatmeanund = r(mean) in `numvar'
	qui reg `X' if und == 1 & samplevar == 1 & sd == 0, cluster(kecnum)
	replace treatmeanund = -1 * _se[_cons] in `numvarse'
	

	qui summ `X' if fpm == 1 & samplevar == 1 & sd == 0
	replace treatmeanfpm = r(mean) in `numvar'
	qui reg `X' if fpm == 1 & samplevar == 1 & sd == 0, cluster(kecnum)
	replace treatmeanfpm = -1 * _se[_cons] in `numvarse'
	
	
	qui summ `X' if und == 0 & fpm == 0 & samplevar == 1 
	replace controlmean = r(mean) in `numvar'
	qui reg `X' if und == 1 & fpm == 0 & samplevar == 1, cluster(kecnum)
	replace controlmean = -1 * _se[_cons] in `numvarse'
	
	
	reg `X' audit undnosd fpmnosd undsd fpmsd if samplevar == 1,  cluster(kecnum)
	replace diffmeansund = _b[undnosd] in `numvar'
	replace diffmeansund  = -1 * _se[undnosd] in `numvarse'
	
	replace diffmeansfpm = _b[fpmnosd] in `numvar'
	replace diffmeansfpm = -1 * _se[fpmnosd] in `numvarse'
	
	
	replace numobs = e(N) in `numvar'
	test undnosd
	replace pvalund = r(p) in `numvar'
	test fpmnosd
	replace pvalfpm = r(p) in `numvar'
	
	areg `X' undnosd fpmnosd undsd fpmsd if samplevar == 1, absorb(kecnum) robust
	replace diffmeansundfe = _b[undnosd] in `numvar'
	replace diffmeansundfe  = -1 * _se[undnosd] in `numvarse'
	
	replace diffmeansfpmfe = _b[fpmnosd] in `numvar'
	replace diffmeansfpmfe = -1 * _se[fpmnosd] in `numvarse'
	
	
	replace numobs = e(N) in `numvar'
	test undnosd
	replace pvalundfe = r(p) in `numvar'
	test fpmnosd
	replace pvalfpmfe = r(p) in `numvar'
	
	
	areg `X' audit undnosd fpmnosd undsd fpmsd if samplevar == 1, absorb(z7enumcode) cluster(kecnum)
	replace diffmeansundengfe = _b[undnosd] in `numvar'
	replace diffmeansundengfe  = -1 * _se[undnosd] in `numvarse'
	
	replace diffmeansfpmengfe = _b[fpmnosd] in `numvar'
	replace diffmeansfpmengfe = -1 * _se[fpmnosd] in `numvarse'
	
	
	replace numobs = e(N) in `numvar'
	test undnosd
	replace pvalundengfe = r(p) in `numvar'
	test fpmnosd
	replace pvalfpmengfe = r(p) in `numvar'
	

			
	local numvar = `numvar' + 1
	
}


*****
* Distributed by schools
*****
foreach X of var lndiffeall4 lndiffeall4mainancil {
	replace samplevar = 1
	
		
	local numvar = `numvar' + 1
	local numvarse = `numvar' + 1
	replace varname = "`X'" in `numvar'
	qui summ `X' if und == 1 & samplevar == 1 & sd == 1
	replace treatmeanund = r(mean) in `numvar'
	qui reg `X' if und == 1 & samplevar == 1 & sd == 1, cluster(kecnum)
	replace treatmeanund = -1 * _se[_cons] in `numvarse'
	

	qui summ `X' if fpm == 1 & samplevar == 1 & sd == 1
	replace treatmeanfpm = r(mean) in `numvar'
	qui reg `X' if fpm == 1 & samplevar == 1 & sd == 1, cluster(kecnum)
	replace treatmeanfpm = -1 * _se[_cons] in `numvarse'
	
	
	qui summ `X' if und == 0 & fpm == 0 & samplevar == 1 
	replace controlmean = r(mean) in `numvar'
	qui reg `X' if und == 1 & fpm == 0 & samplevar == 1, cluster(kecnum)
	replace controlmean = -1 * _se[_cons] in `numvarse'
	
	
	reg `X' audit undnosd fpmnosd undsd fpmsd if samplevar == 1,  cluster(kecnum)
	replace diffmeansund = _b[undsd] in `numvar'
	replace diffmeansund  = -1 * _se[undsd] in `numvarse'
	
	replace diffmeansfpm = _b[fpmsd] in `numvar'
	replace diffmeansfpm = -1 * _se[fpmsd] in `numvarse'
	
	
	replace numobs = e(N) in `numvar'
	test undsd
	replace pvalund = r(p) in `numvar'
	test fpmsd
	replace pvalfpm = r(p) in `numvar'
	
	areg `X' undnosd fpmnosd undsd fpmsd if samplevar == 1, absorb(kecnum) robust
	replace diffmeansundfe = _b[undsd] in `numvar'
	replace diffmeansundfe  = -1 * _se[undsd] in `numvarse'
	
	replace diffmeansfpmfe = _b[fpmsd] in `numvar'
	replace diffmeansfpmfe = -1 * _se[fpmsd] in `numvarse'
	
	
	replace numobs = e(N) in `numvar'
	test undsd
	replace pvalundfe = r(p) in `numvar'
	test fpmsd
	replace pvalfpmfe = r(p) in `numvar'
	
	
	areg `X' audit undnosd fpmnosd undsd fpmsd if samplevar == 1, absorb(z7enumcode) cluster(kecnum)
	replace diffmeansundengfe = _b[undsd] in `numvar'
	replace diffmeansundengfe  = -1 * _se[undsd] in `numvarse'
	
	replace diffmeansfpmengfe = _b[fpmsd] in `numvar'
	replace diffmeansfpmengfe = -1 * _se[fpmsd] in `numvarse'
	
	
	replace numobs = e(N) in `numvar'
	test undsd
	replace pvalundengfe = r(p) in `numvar'
	test fpmsd
	replace pvalfpmengfe = r(p) in `numvar'
	
	
			
	local numvar = `numvar' + 1
	
}

outsheet varname controlmean treatmeanund diffmeansund pvalund diffmeansundengfe pvalundengfe diffmeansundfe pvalundfe numobs using tableinvitemeanssd.out in 1/`numvar', replace
outsheet varname controlmean treatmeanfpm diffmeansfpm pvalfpm diffmeansfpmengfe pvalfpmengfe diffmeansfpmfe pvalfpmfe numobs using tablecommentmeanssd.out in 1/`numvar', replace


**************************************
* Table 8 - Nepotism results
**************************************


use jpehouseholddata, replace


xi: areg zhhworkedwageanyhh  audit und fpm auditzknowsfamilygovt zavgadultedyearsinhh activitiesnumberpercapita   zage zfemale zlhhexpcap zknowsfamilygovt zknowsfamilyH  i.zrespondtype zrespondlate, cluster(kecnum) absorb(auditstrat)
local fe = e(df_a)
if `fe' == . {
	local fe = 0	
}
local depvar = e(depvar)
qui summ `depvar' if e(sample) 
outreg audit zknowsfamilygovt zknowsfamilyH activitiesnumberpercapita  auditzknowsfamilygovt using tableauditnep, 3aster coefastr se adds("Mean dep. var",r(mean),"FE",`fe') replace title ("Nepotism")

xi: areg zhhworkedwageanyhh  audit und fpm  auditzknowsfamilyH zavgadultedyearsinhh zage zfemale activitiesnumberpercapita  zlhhexpcap zknowsfamilygovt zknowsfamilyH  i.zrespondtype zrespondlate, cluster(kecnum) absorb(auditstrat) 
local fe = e(df_a)
if `fe' == . {
	local fe = 0	
}
local depvar = e(depvar)
qui summ `depvar' if e(sample) 
outreg audit zknowsfamilygovt zknowsfamilyH auditzknowsfamilyH activitiesnumberpercapita  using tableauditnep, 3aster coefastr se adds("Mean dep. var",r(mean),"FE",`fe') append

xi: areg zhhworkedwageanyhh  audit  und fpm auditactivitiesnumberpercapita   zavgadultedyearsinhh zage zfemale  activitiesnumberpercapita  zlhhexpcap zknowsfamilygovt zknowsfamilyH  i.zrespondtype zrespondlate, cluster(kecnum) absorb(auditstrat) 
local fe = e(df_a)
if `fe' == . {
	local fe = 0	
}
local depvar = e(depvar)
qui summ `depvar' if e(sample) 
outreg audit zknowsfamilygovt zknowsfamilyH auditactivitiesnumberpercapita   activitiesnumberpercapita  using tableauditnep, 3aster coefastr se adds("Mean dep. var",r(mean),"FE",`fe') append


xi: areg zhhworkedwageanyhh  audit und fpm auditzknowsfamilygovt auditzknowsfamilyH auditactivitiesnumberpercapita    zavgadultedyearsinhh  activitiesnumberpercapita  zage zfemale zlhhexpcap zknowsfamilygovt zknowsfamilyH  i.zrespondtype zrespondlate, cluster(kecnum) absorb(auditstrat) 
local fe = e(df_a)
if `fe' == . {
	local fe = 0	
}
local depvar = e(depvar)
qui summ `depvar' if e(sample) 
outreg audit zknowsfamilygovt zknowsfamilyH auditzknowsfamilygovt auditzknowsfamilyH auditactivitiesnumberpercapita   activitiesnumberpercapita  using tableauditnep, 3aster coefastr se adds("Mean dep. var",r(mean),"FE",`fe') append



**************************************
* Table 9: Participation first stage
**************************************
use jpemeetingdata, clear

areg totaltanyone und fpm musdpj2 musdpj3 if musdpj1 | musdpj2 | musdpj3,  cluster(desaid) absorb(kecnum)
local depvar = e(depvar)
test und = fpm
local undfpmsame = r(p)
qui summ `depvar' if e(sample) 
outreg using tableundfpmfirststage, 3aster coefastr se adds("Mean dep. var",r(mean),"P-value Invitations = Invitations + Comment Forms", `undfpmsame') replace title("First stage") bd(2)

areg totaltperson und fpm musdpj2 musdpj3 if musdpj1 | musdpj2 | musdpj3,  cluster(desaid) absorb(kecnum)
local depvar = e(depvar)
test und = fpm
local undfpmsame = r(p)
qui summ `depvar' if e(sample) 
outreg using tableundfpmfirststage, 3aster coefastr se adds("Mean dep. var",r(mean),"P-value Invitations = Invitations + Comment Forms", `undfpmsame') append bd(2)

areg totalttalk und fpm musdpj2 musdpj3 if musdpj1 | musdpj2 | musdpj3,  cluster(desaid) absorb(kecnum)
local depvar = e(depvar)
test und = fpm
local undfpmsame = r(p)
qui summ `depvar' if e(sample) 
outreg using tableundfpmfirststage, 3aster coefastr se adds("Mean dep. var",r(mean),"P-value Invitations = Invitations + Comment Forms", `undfpmsame') append

areg totalttalktperson und fpm musdpj2 musdpj3 if musdpj1 | musdpj2 | musdpj3,  cluster(desaid) absorb(kecnum)
local depvar = e(depvar)
test und = fpm
local undfpmsame = r(p)
qui summ `depvar' if e(sample) 
outreg using tableundfpmfirststage, 3aster coefastr se adds("Mean dep. var",r(mean),"P-value Invitations = Invitations + Comment Forms", `undfpmsame') append


******************************
* Table 10: Problem resolution
******************************

use jpeproblemdata,clear


areg numprobs  und fpm musdpj2 musdpj3  if musdpj1 | musdpj2 | musdpj3, cluster(desaid) absorb(kecnum)
local depvar = e(depvar)
test und = fpm
local undfpmsame = r(p)
qui summ `depvar' if e(sample) 
outreg using tableundfpmprobres, 3aster coefastr se adds("Mean dep. var",r(mean),"P-value Invitations = Invitations + Comment Forms", `undfpmsame') replace title("Number of problems")

areg anypeny  und fpm musdpj2 musdpj3 if musdpj1 | musdpj2 | musdpj3, cluster(desaid) absorb(kecnum)
local depvar = e(depvar)
test und = fpm
local undfpmsame = r(p)
qui summ `depvar' if e(sample) 
outreg using tableundfpmprobres, 3aster coefastr se adds("Mean dep. var",r(mean),"P-value Invitations = Invitations + Comment Forms", `undfpmsame') append

**************************************
* Resolution of Problems at village-meeting level
**************************************

areg anysevere   und fpm musdpj2 musdpj3  if (musdpj1 | musdpj2 | musdpj3  ), cluster(desaid) absorb(kecnum)
local depvar = e(depvar)
test und = fpm
local undfpmsame = r(p)
qui summ `depvar' if e(sample) 
outreg using tableundfpmprobres, 3aster coefastr se adds("Mean dep. var",r(mean),"P-value Invitations = Invitations + Comment Forms", `undfpmsame') append


****************
* Tabulate audit findings for Table 7
****************
use jpeauditdata
summ anyproblem anyfisik anyadmin k02_abk k03_bkk k07_bmk k09_btk k14_pbk k25_bk

